Crate greenfield
source ·Expand description
greenfield image format
A create for reading and writing the greenfield image format. For a description of the format,
see image.
Also, it includes some utilities for manipulating images in the greenfield format, like quantization, dithering and conversion to other formats.
Modules
Color formats, implementations and conversions.
A greenfield image representation
IO output of the Greenfield image format
Pixel type and related functions/methos for pixel manipulation.
Create prelude
Rgb quantization data structures and algorithms for greenfield images.
Enums
Error type for the greenfield crate
Type Definitions
A wrapper around
std::result::Result with the error type set to GreenfieldError.